@@ -41,9 +41,7 @@
 #include "Command.h"
 #include "DownloadEngine.h"
 #include "DownloadContext.h"
-#include "RequestGroupMan.h"
-#include "CheckIntegrityEntry.h"
-#include "ServerStatMan.h"
+#include "FileEntry.h"
 
 namespace aria2 {
 
@@ -58,6 +56,8 @@ void BtFileAllocationEntry::prepareForNextAction
   BtSetup().setup(commands, getRequestGroup(), e,
                   getRequestGroup()->getOption().get());
   if(!getRequestGroup()->downloadFinished()) {
+    // For DownloadContext::resetDownloadStartTime(), see also
+    // RequestGroup::createInitialCommand()
     getRequestGroup()->getDownloadContext()->resetDownloadStartTime();
     const std::vector<SharedHandle<FileEntry> >& fileEntries =
       getRequestGroup()->getDownloadContext()->getFileEntries();
