@@ -131,14 +131,15 @@
     "                              This may take some time depending on the size of\n" \
     "                              the file.\n"                         \
     "                              If you are using newer file systems such as ext4\n" \
-    "                              (with extents support), btrfs or xfs, 'falloc' is\n" \
-    "                              your best choice. It allocates large(few GiB)\n" \
-    "                              files almost instantly. Don't use 'falloc' with\n" \
-    "                              legacy file systems such as ext3 because it takes\n" \
-    "                              almost same time as 'prealloc' and it blocks aria2\n" \
-    "                              entirely until allocation finishes. 'falloc' may\n" \
-    "                              not be available if your system doesn't have\n" \
-    "                              posix_fallocate() function.")
+    "                              (with extents support), btrfs, xfs or NTFS\n" \
+    "                              (MinGW build only), 'falloc' is your best\n"   \
+    "                              choice. It allocates large(few GiB) files\n" \
+    "                              almost instantly. Don't use 'falloc' with legacy\n" \
+    "                              file systems such as ext3 and FAT32 because it\n" \
+    "                              takes almost same time as 'prealloc' and it\n" \
+    "                              blocks aria2 entirely until allocation finishes.\n" \
+    "                              'falloc' may not be available if your system\n" \
+    "                              doesn't have posix_fallocate() function.")
 #define TEXT_NO_FILE_ALLOCATION_LIMIT                                   \
   _(" --no-file-allocation-limit=SIZE No file allocation is made for files whose\n" \
     "                              size is smaller than SIZE.\n"        \
@@ -668,7 +669,10 @@
     "                              You can pass this output file to aria2c with -i\n" \
     "                              option on restart. Please note that downloads\n" \
     "                              added by aria2.addTorrent and aria2.addMetalink\n" \
-    "                              RPC method are not saved.")
+    "                              RPC method and whose metadata could not be saved\n" \
+    "                              as a file will not be saved. Downloads removed\n" \
+    "                              using aria2.remove and aria2.forceRemove will not\n" \
+    "                              be saved.")
 #define TEXT_MAX_CONNECTION_PER_SERVER          \
   _(" -x, --max-connection-per-server=NUM The maximum number of connections to one\n" \
     "                              server for each download.")
@@ -780,3 +784,35 @@
   _(" --xml-rpc-listen-all[=true|false] Deprecated. Use --rpc-listen-all instead.")
 #define TEXT_XML_RPC_LISTEN_PORT                                        \
   _(" --xml-rpc-listen-port=PORT   Deprecated. Use --rpc-listen-port instead.")
+#define TEXT_SHOW_CONSOLE_READOUT                                       \
+  _(" --show-console-readout[=true|false] Show console readout.")
+#define TEXT_METALINK_BASE_URI                  \
+  _(" --metalink-base-uri=URI      Specify base URI to resolve relative URI in\n" \
+    "                              metalink:url and metalink:metaurl element in a\n" \
+    "                              metalink file stored in local disk. If URI points\n" \
+    "                              to a directory, URI must end with '/'.")
+#define TEXT_STREAM_PIECE_SELECTOR              \
+  _(" --stream-piece-selector=SELECTOR Specify piece selection algorithm\n" \
+    "                              used in HTTP/FTP download. Piece means fixed\n" \
+    "                              length segment which is downloaded in parallel\n" \
+    "                              in segmented download. If 'default' is given,\n" \
+    "                              aria2 selects piece so that it reduces the\n" \
+    "                              number of establishing connection. This is\n" \
+    "                              reasonable default behaviour because\n" \
+    "                              establishing connection is an expensive\n" \
+    "                              operation.\n"                        \
+    "                              If 'inorder' is given, aria2 selects piece which\n" \
+    "                              has minimum index. Index=0 means first of the\n" \
+    "                              file. This will be useful to view movie while\n" \
+    "                              downloading it. --enable-http-pipelining option\n" \
+    "                              may be useful to reduce reconnection overhead.\n" \
+    "                              Please note that aria2 honors\n"     \
+    "                              --min-split-size option, so it will be necessary\n" \
+    "                              to specify a reasonable value to\n"  \
+    "                              --min-split-size option.")
+#define TEXT_TRUNCATE_CONSOLE_READOUT                                   \
+  _(" --truncate-console-readout[=true|false] Truncate console readout to fit in\n"\
+    "                              a single line.")
+#define TEXT_PAUSE                              \
+  _(" --pause[=true|false]         Pause download after added. This option is\n" \
+    "                              effective only when --enable-rpc=true is given.")
