@@ -14,6 +14,7 @@
 #include "ServerStat.h"
 #include "File.h"
 #include "array_fun.h"
+#include "RecoverableException.h"
 
 namespace aria2 {
 
@@ -27,12 +28,12 @@ class RequestGroupManTest : public CppUnit::TestFixture {
   CPPUNIT_TEST(testChangeReservedGroupPosition);
   CPPUNIT_TEST_SUITE_END();
 private:
-  SharedHandle<Option> _option;
+  SharedHandle<Option> option_;
 public:
   void setUp()
   {
     RequestGroup::resetGIDCounter();
-    _option.reset(new Option());
+    option_.reset(new Option());
   }
 
   void testIsSameFileBeingDownloaded();
@@ -47,8 +48,8 @@ CPPUNIT_TEST_SUITE_REGISTRATION( RequestGroupManTest );
 
 void RequestGroupManTest::testIsSameFileBeingDownloaded()
 {
-  SharedHandle<RequestGroup> rg1(new RequestGroup(_option));
-  SharedHandle<RequestGroup> rg2(new RequestGroup(_option));
+  SharedHandle<RequestGroup> rg1(new RequestGroup(option_));
+  SharedHandle<RequestGroup> rg2(new RequestGroup(option_));
 
   SharedHandle<DownloadContext> dctx1
     (new DownloadContext(0, 0, "aria2.tar.bz2"));
@@ -59,7 +60,7 @@ void RequestGroupManTest::testIsSameFileBeingDownloaded()
   rg2->setDownloadContext(dctx2);
 
   RequestGroupMan gm(std::vector<SharedHandle<RequestGroup> >(), 1,
-                     _option.get());
+                     option_.get());
 
   gm.addRequestGroup(rg1);
   gm.addRequestGroup(rg2);
@@ -80,10 +81,10 @@ void RequestGroupManTest::testGetInitialCommands()
 void RequestGroupManTest::testSaveServerStat()
 {
   RequestGroupMan rm
-    (std::vector<SharedHandle<RequestGroup> >(),0,_option.get());
+    (std::vector<SharedHandle<RequestGroup> >(),0,option_.get());
   SharedHandle<ServerStat> ss_localhost(new ServerStat("localhost", "http"));
   rm.addServerStat(ss_localhost);
-  File f("/tmp/aria2_RequestGroupManTest_testSaveServerStat");
+  File f(A2_TEST_OUT_DIR"/aria2_RequestGroupManTest_testSaveServerStat");
   if(f.exists()) {
     f.remove();
   }
@@ -97,32 +98,32 @@ void RequestGroupManTest::testSaveServerStat()
 
 void RequestGroupManTest::testLoadServerStat()
 {
-  File f("/tmp/aria2_RequestGroupManTest_testLoadServerStat");
+  File f(A2_TEST_OUT_DIR"/aria2_RequestGroupManTest_testLoadServerStat");
   std::ofstream o(f.getPath().c_str(), std::ios::binary);
   o << "host=localhost, protocol=http, dl_speed=0, last_updated=1219505257,"
     << "status=OK";
   o.close();
 
   RequestGroupMan rm
-    (std::vector<SharedHandle<RequestGroup> >(),0,_option.get());
+    (std::vector<SharedHandle<RequestGroup> >(),0,option_.get());
   std::cerr << "testLoadServerStat" << std::endl;
   CPPUNIT_ASSERT(rm.loadServerStat(f.getPath()));
   SharedHandle<ServerStat> ss_localhost = rm.findServerStat("localhost",
                                                             "http");
-  CPPUNIT_ASSERT(!ss_localhost.isNull());
+  CPPUNIT_ASSERT(ss_localhost);
   CPPUNIT_ASSERT_EQUAL(std::string("localhost"), ss_localhost->getHostname());
 }
 
 void RequestGroupManTest::testChangeReservedGroupPosition()
 {
   SharedHandle<RequestGroup> gs[] = {
-    SharedHandle<RequestGroup>(new RequestGroup(_option)),
-    SharedHandle<RequestGroup>(new RequestGroup(_option)),
-    SharedHandle<RequestGroup>(new RequestGroup(_option)),
-    SharedHandle<RequestGroup>(new RequestGroup(_option))
+    SharedHandle<RequestGroup>(new RequestGroup(option_)),
+    SharedHandle<RequestGroup>(new RequestGroup(option_)),
+    SharedHandle<RequestGroup>(new RequestGroup(option_)),
+    SharedHandle<RequestGroup>(new RequestGroup(option_))
   };
   std::vector<SharedHandle<RequestGroup> > groups(vbegin(gs), vend(gs));
-  RequestGroupMan rm(groups, 0, _option.get());
+  RequestGroupMan rm(groups, 0, option_.get());
 
   CPPUNIT_ASSERT_EQUAL
     ((size_t)0, rm.changeReservedGroupPosition(1, 0, RequestGroupMan::POS_SET));
